toggle_bit

Function toggle_bit 

pub unsafe fn toggle_bit<T>(address: *const T, bit: u8)
Sets and then Clears a bit at the given address atomically, using the bit- banding feature.

Safety

We take a const pointer and mutate it, but that’s because the svd2rust crate will only give us const pointers.