EepromAddress

Struct EepromAddress 

pub struct EepromAddress { /* private fields */ }
Struct used to pack the block and offset

Implementations

Source

impl EepromAddress

pub fn new(block: usize, offset: usize) -> Self

Creates a new EepromAddres with configured block and offset

pub fn block(&self) -> usize

Returns the block

pub fn offset(&self) -> usize

Returns the offset

pub fn increment(&mut self, offset_size: usize, block_size: usize) -> &mut Self

Increments the offset by one, if that would cause an overflow, increment the block. If both the block and offset wrap, the output for the new block and offset will both be 0.