Module sysctl

Module sysctl 

Code for the System Control module.

Modules

chip_id
This module is all about identifying the physical chip we’re running on.

Structs

Clocks
Frozen clock frequencies

Enums

PowerState
Select whether the peripheral should be on or off
RunMode
Select in which mode the peripheral should be affected